function isButtonHovered (button)			-- Defines a local function named isButtonHovered that takes a table named button as an argument.
	
	local font = button.font or love.graphics.getFont( )	-- Gets the font property of the button table or uses the default font if it's not defined.
	local width = font:getWidth(button.text)	--Calculates the width of the button's text using the font.
	local height = font:getHeight( )			--Gets the height of the font.
	local sx, sy = button.sx or 1, button.sy or button.sx or 1	--Gets the scaling properties of the button or sets them to 1 if they're not defined.
	local x, y = button.x, button.y		--Gets the position of the button.
	local w, h = width*sx, height*sy	--Calculates the width and height of the button using the scaling properties.
	local mx, my = love.mouse.getPosition()	--Gets the position of the mouse.
	
	
	emulatedmousexscale=(emulatedmousex/64)*1.34
	emulatedmouseyscale=(emulatedmousey/45)
	
	local gx, gy = emulatedmousexscale*48, emulatedmouseyscale*46
	if (mx >= x and mx <= x+w		--Checks whether the mouse is within the bounds of the button.
	and my >= y and my <= y+h) 
	or ((gx+1) >= x and (gx-1) <= x+w		--Checks whether the mouse is within the bounds of the button.
	and (gy+1) >= y and (gy-1) <= y+h) 
	then	-- Checks whether the y-coordinate of the mouse is within the y-bounds of the button.
		button.w, button.h = w, h	-- If the mouse is within the bounds of the button, sets the width and height of the button to the computed values of w and h.
		return true					-- Returns true to indicate that the button is being hovered over.
	end
	return false	-- If the mouse is not within the bounds of the button, returns false to indicate that the button is not being hovered over.
	
end


--[[This code defines a function drawButton that takes three parameters: button, hovered, and text.
This function is used to draw a button on the screen with the specified properties.--]]

function drawButton (button, hovered,text)	--Defines a function drawButton with three parameters: button, hovered, and text.
	drawButtonFocus()
	love.graphics.setFont( button.font )	--Sets the font of the button to the font specified in button.font.
	
	if hovered then									--If the button is being hovered over, 
		love.graphics.setColor(button.hoveredColor)	--the button color is set to button.hoveredColor, 
		
						
		--reloadadjustedcolors()						--the adjusted colors are reloaded, 
		love.graphics.rectangle ('line', button.x, button.y, button.w, button.h)	--and a rectangle is drawn around the button using love.graphics.rectangle.
	else	--If the button is not being hovered over, the button color is set to button.color, the adjusted colors are reloaded.
		love.graphics.setColor(button.color)
		--reloadadjustedcolors()
	end
	if gamestatus=="levelEditor" then
		hideLevelEditorButtons(button, hovered,text)	-- function called from game/status/leveleditorButtons.lua
	end
	love.graphics.print(button.text,button.x,button.y,button.r,button.sx)	--Prints the specified text on the button at the position specified by button.x and button.y with the specified rotation button.r and scale button.sx.
	
	--updateButtonAlpha(button)
	updateButtonZoom(button)
	
end

-- draw the particle sparkles
function drawSparkleParticles()
    love.graphics.setColor(1, 1, 1, 0.8)
    for _, sparkle in ipairs(sparkleParticles) do
        love.graphics.circle('fill', sparkle.x, sparkle.y, sparkle.size)
    end
   
end

function updateButtonFocus(dt)
    -- Update pulsating effect
    pulsateTimer = pulsateTimer + dt
    if pulsateTimer >= 1 then
        pulsateTimer = 0
    end

    -- Update particle sparkles
    for i, sparkle in ipairs(sparkleParticles) do
        sparkle.x = sparkle.x + sparkle.speed * dt
        sparkle.y = sparkle.y + sparkle.speed * dt

        -- Remove sparkles that go off-screen
        if sparkle.x > love.graphics.getWidth() or sparkle.y > love.graphics.getHeight() then
            table.remove(sparkleParticles, i)
        end
    end
end

-- In your game update function (e.g., love.update), update the alpha when hovered for any button
function updateButtonAlpha(button)
    if isButtonHovered(button) then
        button.alpha = math.min(1, button.alpha + 0.05 ) -- Increase alpha gradually
    else
        button.alpha = math.max(0, button.alpha - 0.05 ) -- Decrease alpha gradually
    end
end

function updateButtonZoom(button)
local hoverScale = 1.2 -- Scale factor when hovered

    if isButtonHovered(button) then
        button.sx = math.min(1.5, button.sx + 0.05) -- Increase scale gradually
		--if button.sx==1.1 then
			--bubbles:play()
		--end
    else
        button.sx = math.max(1, button.sx - 0.05) -- Decrease scale gradually
		
    end
end


function buttonfocusanimations()

-- Implement the pulsating effect on the buttons
    local focusColorShift = math.abs(math.sin(pulsateTimer * math.pi))
    
			if timer2>1 then --love.graphics.setColor(0, 1 - focusColorShift, 0, 1)
							love.graphics.setColor(0,1,0,1) 
								gamepadselectanimation=false
			elseif timer2<1 then love.graphics.setColor(0,timer2,timer2-1,1)
			end	
			
					if gamepadselectanimation==false then
				elseif gamepadselectanimation==true then
						if timer2<3 then fwidth=100+timer2*40 fheight=20+timer2*40
						end
						
				end
end



function drawButtonFocus()

		
	buttonfocusanimations()		-- focus color and size animations
		
	--if bfocus=="exit" or bfocus=="extras" or bfocus=="ends" or bfocus=="save" or bfocus=="reset" or bfocus=="music" or bfocus=="credits" or bfocus=="options" then	
	--end
	
	
	--level menu
		if bfocus=="exit" 	then love.graphics.rectangle ('line', exitButton.x, exitButton.y, fwidth, fheight)		--fwidth and fheight are the size variables used for the button focus animations
	elseif bfocus=="extras" then love.graphics.rectangle ('line', extrasButton.x, extrasButton.y, fwidth, fheight)
	elseif bfocus=="ends" 	then love.graphics.rectangle ('line', endButton.x, endButton.y, fwidth, fheight)
	elseif bfocus=="save" 	then love.graphics.rectangle ('line', saveButton.x, saveButton.y, fwidth, fheight)
	elseif bfocus=="reset" 	then love.graphics.rectangle ('line', resetsavegameButton.x, resetsavegameButton.y, fwidth, fheight)
	elseif bfocus=="music" 	then love.graphics.rectangle ('line', musicButton.x, musicButton.y, fwidth, fheight)
	elseif bfocus=="options" then love.graphics.rectangle ('line', optionsButton.x, optionsButton.y, fwidth, fheight)
	elseif bfocus=="credits" then love.graphics.rectangle ('line', creditsButton.x, creditsButton.y, fwidth, fheight)
	elseif bfocus=="rejectexit" then love.graphics.rectangle ('line', rejectexitButton.x, rejectexitButton.y, fwidth, fheight)
	elseif bfocus=="confirmexit" then love.graphics.rectangle ('line', confirmexitButton.x, confirmexitButton.y, fwidth, fheight)
	elseif bfocus=="confirmsave" then love.graphics.rectangle ('line', confirmsaveButton.x, confirmsaveButton.y, fwidth, fheight)
	elseif bfocus=="rejectsave" then love.graphics.rectangle ('line', rejectsaveButton.x, rejectsaveButton.y, fwidth, fheight)
	end
	
	-- After drawing all the button outlines, draw the particle sparkles
    --drawSparkleParticles()
	
end
