function loadCustomLevel(filename)
    local level = {}
    
    -- Get the default save directory path
    local saveDir = love.filesystem.getIdentity()
    
    -- Construct the full path to the custom level file
    local fullPath = love.filesystem.getSaveDirectory() .. "/" .. saveDir .. "/" .. filename

    -- Load the level data from the file
    local success, data = love.filesystem.read(fullPath)

    if not success then
        print("Failed to load custom level from file: " .. fullPath)
        return nil
    end

    -- Execute the loaded Lua code to populate the 'level' table
    local loadFunction, errorMsg = load(data, "Custom Level", "t", level)

    if not loadFunction then
        print("Error loading custom level from file: " .. fullPath)
        print(errorMsg)
        return nil
    end

    local status, error = pcall(loadFunction)

    if not status then
        print("Error executing custom level from file: " .. fullPath)
        print(error)
        return nil
    end

    return level
end

function listCustomLevels()
    local dirItems = love.filesystem.getDirectoryItems(love.filesystem.getSaveDirectory())  -- Use the default save directory
    
    for _, item in ipairs(dirItems) do
        if item:match("%.lua$") then
            table.insert(customLevels, item)
        end
    end
end

function selectCustomLevelWithMouse()
  for i, levelFile in ipairs(customLevels) do
        local x = 100  -- Adjust the x-position based on your layout
        local y = 100 + i * 30  -- Adjust the y-position based on your layout
        local width = 100  -- Adjust the button width
        local height = 30  -- Adjust the button height

        local hovered = isButtonHovered(x, y, width, height)
        drawButton(x, y, width, height, hovered, levelFile)

        if hovered and love.mouse.isDown(1) then
            local selectedLevel = loadCustomLevel(levelFile)

            if selectedLevel then
                -- Start the game with the selected custom level
                startGame(selectedLevel)
            end
        end
    end
    return nil
end




function drawCustomLevels()
        -- Draw the custom level selection menu here
    
    for i, levelFile in ipairs(customLevels) do
        local x = 100  -- Adjust the x-position based on your layout
        local y = 100 + i * 30  -- Adjust the y-position based on your layout
        local width = 100  -- Adjust the button width
        local height = 30  -- Adjust the button height

        local hovered = isCustomLevelButtonHovered(x, y, width, height)
        drawCustomLevelButton(x, y, width, height, hovered, levelFile)

        if hovered and love.mouse.isDown(1) then
            local selectedLevel = loadCustomLevel(levelFile)

            if selectedLevel then
                -- Start the game with the selected custom level
                startGame(selectedLevel)
            end
        end
    end
end

-- Implement a function to check if the mouse is hovering over a button
function isCustomLevelButtonHovered(x, y, width, height)
    local mouseX, mouseY = love.mouse.getPosition()
    return mouseX >= x and mouseX <= x + width and mouseY >= y and mouseY <= y + height
end

-- Implement a function to draw a button
function drawCustomLevelButton(x, y, width, height, hovered, text)
    love.graphics.setColor(0.5, 0.5, 0.5)  -- Gray color
    if hovered then
        love.graphics.setColor(1, 1, 1)  -- White color when hovered
    end
    love.graphics.rectangle("fill", x, y, width, height)
    love.graphics.setColor(0, 0, 0)  -- Black text color
    love.graphics.print(text, x + 10, y + 5)  -- Adjust text position
    love.graphics.setColor(1, 1, 1)  -- Reset color to white
end
